Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/base/ship.h')
-rw-r--r--src/game/base/ship.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/game/base/ship.h b/src/game/base/ship.h
index e8a6505..d627295 100644
--- a/src/game/base/ship.h
+++ b/src/game/base/ship.h
@@ -20,6 +20,7 @@ const float MIN_DELTA = 0.000001f;
// planet docking distance
const float PLANET_SAFE_DISTANCE = 50.0f;
+const float COMBAT_DISTANCE = 100.0f;
/**
@@ -28,7 +29,7 @@ const float PLANET_SAFE_DISTANCE = 50.0f;
class Ship : public core::EntityControlable
{
public:
- enum AutoPilotFlags { AutoPilotDisabled = 0, AutoPilotEnabled = 1, AutoPilotDock = 2, AutoPilotFormation = 4 };
+ enum AutoPilotFlags { AutoPilotDisabled = 0, AutoPilotEnabled = 1, AutoPilotDock = 2, AutoPilotFormation = 4, AutoPilotCombat = 8 };
Ship(core::Player *owner, const ShipModel *shipmodel);
~Ship();
@@ -234,7 +235,12 @@ protected:
void frame_autopilot_goto(const unsigned long elapsed, core::Entity *target);
/**
- * @brief autopilot goto target
+ * @brief autopilot combat
+ * */
+ void frame_autopilot_combat(const unsigned long elapsed, core::Entity *target);
+
+ /**
+ * @brief autopilo dock target
* */
void frame_autopilot_dock(const unsigned long elapsed, core::Entity *target);